Index: modules/overlay/overlay-parent.js
===================================================================
RCS file: /cvs/drupal/drupal/modules/overlay/overlay-parent.js,v
retrieving revision 1.22
diff -u -r1.22 overlay-parent.js
--- modules/overlay/overlay-parent.js	14 Jan 2010 04:06:54 -0000	1.22
+++ modules/overlay/overlay-parent.js	25 Jan 2010 15:17:32 -0000
@@ -685,9 +685,10 @@
   }
 
   var href = $target.attr('href');
-  // Only continue if link has an href attribute and is not just linking to
-  // an anchor.
-  if (href != undefined && href != '' && href.charAt(0) != '#') {
+  var protocol = $target.get(0).protocol;
+  // Only continue if link has an href attribute, uses the http or https
+  // protocol and is not just linking to an anchor.
+  if (href != undefined && href != '' && href.charAt(0) != '#' && (protocol == 'http:' || protocol == 'https:')) {
     // Open admin links in the overlay.
     if (self.isAdminLink(href)) {
       href = self.fragmentizeLink($target.get(0));
